function varargout = obr_T20(varargin)
% OBR_T20 M-file for obr_T20.fig
%      OBR_T20, by itself, creates a new OBR_T20 or raises the existing
%      singleton*.
%
%      H = OBR_T20 returns the handle to a new OBR_T20 or the handle to
%      the existing singleton*.
%
%      OBR_T20('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in OBR_T20.M with the given input arguments.
%
%      OBR_T20('Property','Value',...) creates a new OBR_T20 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before obr_T20_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to obr_T20_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help obr_T20

% Last Modified by GUIDE v2.5 26-Apr-2011 15:34:50

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @obr_T20_OpeningFcn, ...
                   'gui_OutputFcn',  @obr_T20_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before obr_T20 is made visible.
function obr_T20_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to obr_T20 (see VARARGIN)

% Choose default command line output for obr_T20
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);
global ir;
global n;
global T20;
global Fs;



    
    [T20,A20,B20] = reverberb_T20(ir,Fs)

    
    axes(handles.axes2); 
        
        xlabel('t[s]'), ylabel('EDT [dB]')
        title('T10');
        line([0,(-60-A20)/(B20)],[A20,-60],'Color','r','LineWidth',.5);
        grid on 
        
        

% UIWAIT makes obr_T20 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = obr_T20_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



% --- Executes during object creation, after setting all properties.
function axes2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axes2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


       
       
         
         
         
% Hint: place code in OpeningFcn to populate axes2


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
  
